Canonical serialization of a licence.
Contract: two structurally equal licences produce identical bytes, on any host, in any JVM. Signatures are computed over these bytes, so any divergence here invalidates every licence in the field.
Canonical serialization of a licence. Contract: two structurally equal licences produce identical bytes, on any host, in any JVM. Signatures are computed over these bytes, so any divergence here invalidates every licence in the field.
(canonical-bytes license)UTF-8 bytes a signature is computed over.
UTF-8 bytes a signature is computed over.
(canonical-string license)Deterministic textual form of license.
Deterministic textual form of `license`.
(decode64 s)Bytes of base64 s, or nil when s is not valid base64.
Bytes of base64 `s`, or nil when `s` is not valid base64.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |